function [ret,x0,str]=scaoqtn7(t,x,u,flag);
%SCAOQTN7	is the M-file description of the SIMULINK system named SCAOQTN7.
%	The block-diagram can be displayed by typing: SCAOQTN7.
%
%	SYS=SCAOQTN7(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCAOQTN7 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCAOQTN7 with a FLAG of zero:
%	[SIZES]=SCAOQTN7([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[4,62,628,460])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',		'RK-45')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'tsim')
set_param(sys,'Min step size',	'20')
set_param(sys,'Max step size',	'20')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')


%     Subsystem  ['Calcul champ magntique',13,'terrestre'].

new_system([sys,'/',['Calcul champ magntique',13,'terrestre']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],'Location',[201,82,825,508])

add_block('built-in/Inport',[sys,'/',['Calcul champ magntique',13,'terrestre/in_2']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/in_2']],...
		'Port','2',...
		'position',[10,160,30,180])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur',13,'d''tat']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur',13,'d''tat']],...
		'position',[53,140,58,145])

add_block('built-in/Inport',[sys,'/',['Calcul champ magntique',13,'terrestre/in_1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/in_1']],...
		'position',[10,115,30,135])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[100,80,105,85])

add_block('built-in/Mux',[sys,'/',['Calcul champ magntique',13,'terrestre/Mux4']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Mux4']],...
		'hide name',0,...
		'inputs','[3 7]',...
		'position',[165,100,200,195])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[471,135,476,140])

add_block('built-in/MATLAB Fcn',[sys,'/',['Calcul champ magntique',13,'terrestre/MATLAB Fcn']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','quatpass(u(7:10))*u(1:3)',...
		'Output Width','3',...
		'Mask Display','CHANGEMENT\nDE BASE',...
		'position',[265,127,365,173])

add_block('built-in/Outport',[sys,'/',['Calcul champ magntique',13,'terrestre/out_1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/out_1']],...
		'Mask Display','',...
		'position',[400,140,420,160])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[35,125;155,125])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[205,150;255,150])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[35,170;155,170])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[370,150;390,150])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],...
		'Mask Display','Calcul du champ\nmagntique terrestre\n(repre satellite)')


%     Finished composite block ['Calcul champ magntique',13,'terrestre'].

set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],...
		'orientation',2,...
		'BackGround',7,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[320,280,455,335])

add_block('built-in/Derivative',[sys,'/','Derivative'])
set_param([sys,'/','Derivative'],...
		'orientation',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[220,295,275,325])

add_block('built-in/Note',[sys,'/','Brel'])
set_param([sys,'/','Brel'],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[215,270,220,275])

add_block('built-in/Note',[sys,'/','B'])
set_param([sys,'/','B'],...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[291,320,296,325])


%     Subsystem  ['Perturbations',13,'arodynamiques'].

new_system([sys,'/',['Perturbations',13,'arodynamiques']])
set_param([sys,'/',['Perturbations',13,'arodynamiques']],'Location',[63,492,687,918])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques/Mux']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Mux']],...
		'inputs','3',...
		'position',[150,57,180,133])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques/Constant1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Constant1']],...
		'hide name',0,...
		'Value','0',...
		'position',[40,60,85,80])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques/Constant2']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Constant2']],...
		'hide name',0,...
		'Value','COUPLE_AERO',...
		'position',[40,85,85,105])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques/Constant3']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Constant3']],...
		'hide name',0,...
		'Value','0',...
		'position',[40,110,85,130])

add_block('built-in/Outport',[sys,'/',['Perturbations',13,'arodynamiques/out_1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/out_1']],...
		'position',[300,85,320,105])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques/MATLAB Fcn1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/MATLAB Fcn1']],...
		'hide name',0,...
		'MATLAB Fcn','u''',...
		'Output Width','3',...
		'position',[215,85,265,115])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[90,70;140,70])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[90,95;140,95])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[90,120;140,120])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[185,95;205,100])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[270,100;290,95])
set_param([sys,'/',['Perturbations',13,'arodynamiques']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['Perturbations',13,'arodynamiques'].

set_param([sys,'/',['Perturbations',13,'arodynamiques']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[25,95,125,145])


%     Subsystem  ['Double click',13,'on this for demo.2'].

new_system([sys,'/',['Double click',13,'on this for demo.2']])
set_param([sys,'/',['Double click',13,'on this for demo.2']],'Location',[-10,380,117,533])
set_param([sys,'/',['Double click',13,'on this for demo.2']],...
		'Mask Display','MODELISATION AVEC COMMANDE MAGNETO-COUPLEURS PAR LA DERIVEE DU CHAMP MAGNETIQUE TERRESTRE',...
		'Mask Type','',...
		'Mask Dialogue',' ',...
		'Mask Translate','')
set_param([sys,'/',['Double click',13,'on this for demo.2']],...
		'Mask Help','')


%     Finished composite block ['Double click',13,'on this for demo.2'].

set_param([sys,'/',['Double click',13,'on this for demo.2']],...
		'ForeGround',2,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[20,10,610,56])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[410,102,460,118])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[345,100,365,120])

add_block('built-in/Note',[sys,'/','Sign:GUIZIOU 1994//95'])
set_param([sys,'/','Sign:GUIZIOU 1994//95'],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[525,60,530,65])

add_block('built-in/Note',[sys,'/','M'])
set_param([sys,'/','M'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[117,185,122,190])

add_block('built-in/Note',[sys,'/',['MOMENT',13,'MAGNETIQUE']])
set_param([sys,'/',['MOMENT',13,'MAGNETIQUE']],...
		'BackGround',6,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[40,265,45,270])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'Gain','0',...
		'position',[145,107,180,133])

add_block('built-in/Note',[sys,'/','Mp'])
set_param([sys,'/','Mp'],...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[170,85,175,90])

add_block('built-in/Note',[sys,'/','Mc'])
set_param([sys,'/','Mc'],...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[215,235,220,240])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'inputs','+-',...
		'position',[90,204,105,231])


%     Subsystem  'UnNamed4'.

new_system([sys,'/','UnNamed4'])
set_param([sys,'/','UnNamed4'],'Location',[4,64,260,245])

add_block('built-in/Outport',[sys,'/','UnNamed4/out_1'])
set_param([sys,'/','UnNamed4/out_1'],...
		'position',[235,85,255,105])

add_block('built-in/Mux',[sys,'/','UnNamed4/Mux'])
set_param([sys,'/','UnNamed4/Mux'],...
		'inputs','3',...
		'position',[150,57,180,133])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant1'])
set_param([sys,'/','UnNamed4/Constant1'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,60,85,80])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant2'])
set_param([sys,'/','UnNamed4/Constant2'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,85,85,105])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant3'])
set_param([sys,'/','UnNamed4/Constant3'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,110,85,130])
add_line([sys,'/','UnNamed4'],[90,70;140,70])
add_line([sys,'/','UnNamed4'],[90,95;140,95])
add_line([sys,'/','UnNamed4'],[90,120;140,120])
add_line([sys,'/','UnNamed4'],[185,95;225,95])
set_param([sys,'/','UnNamed4'],...
		'Mask Display','Consigne\nnulle')


%     Finished composite block 'UnNamed4'.

set_param([sys,'/','UnNamed4'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[5,190,65,230])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'orientation',2,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'Gain','0',...
		'position',[150,297,185,323])


%     Subsystem  ['Calcul couples',13,'de commande'].

new_system([sys,'/',['Calcul couples',13,'de commande']])
set_param([sys,'/',['Calcul couples',13,'de commande']],'Location',[4,64,628,490])

add_block('built-in/Inport',[sys,'/',['Calcul couples',13,'de commande/in_4']])
set_param([sys,'/',['Calcul couples',13,'de commande/in_4']],...
		'Port','2',...
		'position',[165,160,185,180])

add_block('built-in/Outport',[sys,'/',['Calcul couples',13,'de commande/out_2']])
set_param([sys,'/',['Calcul couples',13,'de commande/out_2']],...
		'position',[355,145,375,165])

add_block('built-in/Inport',[sys,'/',['Calcul couples',13,'de commande/in_3']])
set_param([sys,'/',['Calcul couples',13,'de commande/in_3']],...
		'position',[165,125,185,145])

add_block('built-in/MATLAB Fcn',[sys,'/',['Calcul couples',13,'de commande/MATLAB Fcn1']])
set_param([sys,'/',['Calcul couples',13,'de commande/MATLAB Fcn1']],...
		'hide name',0,...
		'MATLAB Fcn','(cross(u(1:3),u(4:6)))''',...
		'Output Width','3',...
		'position',[285,140,335,170])

add_block('built-in/Mux',[sys,'/',['Calcul couples',13,'de commande/Mux1']])
set_param([sys,'/',['Calcul couples',13,'de commande/Mux1']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[220,115,260,190])

add_block('built-in/Note',[sys,'/',['Calcul couples',13,'de commande/CALCUL DU COUPLE DE COMMANDE POUR  UNE COMMANDE',13,' PAR  LA DERIVEE DU CHAMP MAGNETIQUE']])
set_param([sys,'/',['Calcul couples',13,'de commande/CALCUL DU COUPLE DE COMMANDE POUR  UNE COMMANDE',13,' PAR  LA DERIVEE DU CHAMP MAGNETIQUE']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',16)
set_param([sys,'/',['Calcul couples',13,'de commande/CALCUL DU COUPLE DE COMMANDE POUR  UNE COMMANDE',13,' PAR  LA DERIVEE DU CHAMP MAGNETIQUE']],...
		'position',[320,15,325,20])
add_line([sys,'/',['Calcul couples',13,'de commande']],[265,155;275,155])
add_line([sys,'/',['Calcul couples',13,'de commande']],[190,135;210,135])
add_line([sys,'/',['Calcul couples',13,'de commande']],[340,155;345,155])
add_line([sys,'/',['Calcul couples',13,'de commande']],[190,170;210,170])
set_param([sys,'/',['Calcul couples',13,'de commande']],...
		'Mask Display','Calcul\ndu couple\nde contrle Mc')


%     Finished composite block ['Calcul couples',13,'de commande'].

set_param([sys,'/',['Calcul couples',13,'de commande']],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[125,205,200,260])

add_block('built-in/Note',[sys,'/','GAIN'])
set_param([sys,'/','GAIN'],...
		'BackGround',6,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[170,325,175,330])


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[50,127,480,322])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant3'])
set_param([sys,'/','UnNamed/Constant3'],...
		'hide name',0,...
		'Value','rayon_orbital',...
		'position',[65,129,155,161])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant2'])
set_param([sys,'/','UnNamed/Constant2'],...
		'hide name',0,...
		'Value','inclinaison',...
		'position',[65,89,155,121])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/MATLAB Fcn'])
set_param([sys,'/','UnNamed/MATLAB Fcn'],...
		'MATLAB Fcn','champmgn(u)',...
		'position',[270,77,395,133])

add_block('built-in/Clock',[sys,'/','UnNamed/Clock'])
set_param([sys,'/','UnNamed/Clock'],...
		'position',[65,55,85,75])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux'])
set_param([sys,'/','UnNamed/Mux'],...
		'inputs','3',...
		'position',[210,48,250,162])

add_block('built-in/Note',[sys,'/','UnNamed/Temps'])
set_param([sys,'/','UnNamed/Temps'],...
		'position',[125,50,130,55])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[415,95,435,115])
add_line([sys,'/','UnNamed'],[255,105;260,105])
add_line([sys,'/','UnNamed'],[160,145;200,145])
add_line([sys,'/','UnNamed'],[90,65;200,65])
add_line([sys,'/','UnNamed'],[160,105;200,105])
add_line([sys,'/','UnNamed'],[400,105;405,105])
set_param([sys,'/','UnNamed'],...
		'Mask Display','CHAMP TERRESTRE\nEN REPERE ORBITAL')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'orientation',2,...
		'hide name',0,...
		'position',[490,274,620,316])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[230,205,250,245])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'mat-name','solution',...
		'buffer','points_trace',...
		'position',[520,217,570,233])

add_block('built-in/Gain',[sys,'/','Gain2'])
set_param([sys,'/','Gain2'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'Gain','0',...
		'position',[260,212,295,238])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[80,385,566,690])

add_block('built-in/Integrator',[sys,'/','UnNamed2/Integrator'])
set_param([sys,'/','UnNamed2/Integrator'],...
		'Initial','etat_init',...
		'position',[310,75,345,105])

add_block('built-in/State-space',[sys,'/','UnNamed2/Matrix gain.'])
set_param([sys,'/','UnNamed2/Matrix gain.'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/','UnNamed2/Matrix gain.'],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','[1/Ir 0 0;0 1/It 0;0 0 1/Il;0 0 0;1 0 0;0 0 0;0 0 0 ]\/')
set_param([sys,'/','UnNamed2/Matrix gain.'],...
		'position',[100,48,155,82])

add_block('built-in/Inport',[sys,'/','UnNamed2/in_1'])
set_param([sys,'/','UnNamed2/in_1'],...
		'position',[25,55,45,75])

add_block('built-in/Outport',[sys,'/','UnNamed2/out_1'])
set_param([sys,'/','UnNamed2/out_1'],...
		'position',[415,80,435,100])

add_block('built-in/Constant',[sys,'/','UnNamed2/Constant1'])
set_param([sys,'/','UnNamed2/Constant1'],...
		'orientation',2,...
		'Value','rotation_orbitale',...
		'position',[235,235,355,265])

add_block('built-in/Constant',[sys,'/','UnNamed2/Constant'])
set_param([sys,'/','UnNamed2/Constant'],...
		'orientation',2,...
		'Value','[Ir It Il]',...
		'position',[235,192,315,218])

add_block('built-in/Mux',[sys,'/','UnNamed2/Mux'])
set_param([sys,'/','UnNamed2/Mux'],...
		'orientation',2,...
		'inputs','[7 3 1]',...
		'position',[180,134,210,276])

add_block('built-in/Sum',[sys,'/','UnNamed2/Sum'])
set_param([sys,'/','UnNamed2/Sum'],...
		'position',[260,44,275,131])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/MATLAB Fcn'])
set_param([sys,'/','UnNamed2/MATLAB Fcn'],...
		'orientation',2,...
		'MATLAB Fcn','der_sys(u)',...
		'Output Width','7',...
		'position',[95,190,145,220])
add_line([sys,'/','UnNamed2'],[50,65;90,65])
add_line([sys,'/','UnNamed2'],[280,90;300,90])
add_line([sys,'/','UnNamed2'],[350,90;405,90])
add_line([sys,'/','UnNamed2'],[360,90;360,160;220,160])
add_line([sys,'/','UnNamed2'],[230,205;220,205])
add_line([sys,'/','UnNamed2'],[230,250;220,250])
add_line([sys,'/','UnNamed2'],[175,205;155,205])
add_line([sys,'/','UnNamed2'],[90,205;70,205;70,110;250,110])
add_line([sys,'/','UnNamed2'],[160,65;250,65])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','DYNAMIQUE\n\nSATELLITE\n\nQUATERNIONS')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'position',[325,189,455,261])
add_line(sys,[110,220;115,220])
add_line(sys,[70,210;80,210])
add_line(sys,[485,295;465,295])
add_line(sys,[370,110;400,110])
add_line(sys,[130,120;135,120])
add_line(sys,[315,310;300,310;300,285;90,285;90,245;115,245])
add_line(sys,[300,310;285,310])
add_line(sys,[215,310;195,310])
add_line(sys,[145,310;75,310;75,225;80,225])
add_line(sys,[205,235;220,235])
add_line(sys,[185,120;205,120;205,215;220,215])
add_line(sys,[460,225;475,225;475,320;465,320])
add_line(sys,[460,225;510,225])
add_line(sys,[255,225;250,225])
add_line(sys,[300,225;315,225])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
