function [ret,x0,str]=scaoqtn8(t,x,u,flag);
%SCAOQTN8	is the M-file description of the SIMULINK system named SCAOQTN8.
%	The block-diagram can be displayed by typing: SCAOQTN8.
%
%	SYS=SCAOQTN8(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCAOQTN8 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCAOQTN8 with a FLAG of zero:
%	[SIZES]=SCAOQTN8([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[30,97,584,446])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',		'RK-23')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'1')
set_param(sys,'Min step size',	'0.002')
set_param(sys,'Max step size',	'0.002')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')

add_block('built-in/Note',[sys,'/','Sign: GUIZIOU 1995'])
set_param([sys,'/','Sign: GUIZIOU 1995'],...
		'position',[490,330,491,331])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Gain','Mgd',...
		'position',[70,127,105,163])

add_block('built-in/Note',[sys,'/',['QUATERNIONS:',13,'ETUDE DU MOUVEMENT DE LAGRANGE ET POISSON']])
set_param([sys,'/',['QUATERNIONS:',13,'ETUDE DU MOUVEMENT DE LAGRANGE ET POISSON']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[285,5,286,6])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn3'])
set_param([sys,'/','MATLAB Fcn3'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','out_x_y(u)',...
		'Output Width','2',...
		'position',[355,126,435,164])

add_block('built-in/Note',[sys,'/',['SORTIE DE LA TRAJECTOIRE',13,'DE L''EXTREMITE DE L''AXE  ',13,'z SUR LE PLAN XOY']])
set_param([sys,'/',['SORTIE DE LA TRAJECTOIRE',13,'DE L''EXTREMITE DE L''AXE  ',13,'z SUR LE PLAN XOY']],...
		'ForeGround',3,...
		'Font Size',12,...
		'position',[440,185,441,186])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',5,...
		'position',[45,248,85,292])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','x_y',...
		'position',[470,137,520,153])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn2'])
set_param([sys,'/','MATLAB Fcn2'],...
		'orientation',2,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','cpl_pes(u)',...
		'Output Width','3',...
		'position',[145,202,250,238])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[80,155,566,460])
open_system([sys,'/','UnNamed2'])

add_block('built-in/Integrator',[sys,'/','UnNamed2/Integrator'])
set_param([sys,'/','UnNamed2/Integrator'],...
		'Initial','etat_init',...
		'position',[310,75,345,105])

add_block('built-in/State-space',[sys,'/','UnNamed2/Matrix gain.'])
set_param([sys,'/','UnNamed2/Matrix gain.'],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/','UnNamed2/Matrix gain.'],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','[1/Ir 0 0;0 1/It 0;0 0 1/Il;0 0 0;1 0 0;0 0 0;0 0 0 ]\/')
set_param([sys,'/','UnNamed2/Matrix gain.'],...
		'position',[100,48,155,82])

add_block('built-in/Inport',[sys,'/','UnNamed2/in_1'])
set_param([sys,'/','UnNamed2/in_1'],...
		'position',[25,55,45,75])

add_block('built-in/Outport',[sys,'/','UnNamed2/out_1'])
set_param([sys,'/','UnNamed2/out_1'],...
		'position',[415,80,435,100])

add_block('built-in/Constant',[sys,'/','UnNamed2/Constant1'])
set_param([sys,'/','UnNamed2/Constant1'],...
		'orientation',2,...
		'Value','rotation_orbitale',...
		'position',[235,235,355,265])

add_block('built-in/Constant',[sys,'/','UnNamed2/Constant'])
set_param([sys,'/','UnNamed2/Constant'],...
		'orientation',2,...
		'Value','[Ir It Il]',...
		'position',[235,192,315,218])

add_block('built-in/Mux',[sys,'/','UnNamed2/Mux'])
set_param([sys,'/','UnNamed2/Mux'],...
		'orientation',2,...
		'inputs','[7 3 1]',...
		'position',[180,134,210,276])

add_block('built-in/Sum',[sys,'/','UnNamed2/Sum'])
set_param([sys,'/','UnNamed2/Sum'],...
		'position',[260,44,275,131])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/MATLAB Fcn'])
set_param([sys,'/','UnNamed2/MATLAB Fcn'],...
		'orientation',2,...
		'MATLAB Fcn','der_sys(u)',...
		'Output Width','7',...
		'position',[95,190,145,220])
add_line([sys,'/','UnNamed2'],[50,65;90,65])
add_line([sys,'/','UnNamed2'],[280,90;300,90])
add_line([sys,'/','UnNamed2'],[350,90;405,90])
add_line([sys,'/','UnNamed2'],[360,90;360,160;220,160])
add_line([sys,'/','UnNamed2'],[230,205;220,205])
add_line([sys,'/','UnNamed2'],[230,250;220,250])
add_line([sys,'/','UnNamed2'],[175,205;155,205])
add_line([sys,'/','UnNamed2'],[90,205;70,205;70,110;250,110])
add_line([sys,'/','UnNamed2'],[160,65;250,65])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','DYNAMIQUE\n\nSATELLITE\n\nQUATERNIONS')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'position',[145,109,275,181])
add_line(sys,[280,145;345,145])
add_line(sys,[110,145;135,145])
add_line(sys,[140,220;20,220;20,145;60,145])
add_line(sys,[325,145;325,220;260,220])
add_line(sys,[440,145;460,145])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
